%%%%%%%%%% LOAD AND PLOT DATA

echo off
load parafac_miles_data

surf(ExAx,EmAx,squeeze(X(1,:,:)));
ylabel('Emission/nm')
xlabel('Excitation/nm')
zlabel('Intensity')
title('Sample 1','FontWeight','Bold','FontSize',12)
axis tight

disp([' 22 samples with ',deblank(Yname(1,:)),', ',deblank(Yname(2,:)),', ',deblank(Yname(3,:)),' & ',deblank(Yname(4,:)),' '])
disp(' measured by fluorescence excitation-emission spectroscopy')
disp(' Note the large amount of Rayleigh scatter on the diagonal')
disp(' Emission wavelength is equal to the excitation wavelength')
disp(' as before after setting emissions to missing')
disp(' ')
disp(' Press any key to continue')
pause


disp(' ')
disp(' Removing emission below excitation')
disp(' ')
x = X;
for i=1:size(X,3),
   j=find(EmAx<ExAx(i));
   x(:,j,i)=NaN;
end

subplot(1,2,1)
surf(ExAx,EmAx,squeeze(X(1,:,:)));
ylabel('Emission/nm')
xlabel('Excitation/nm')
zlabel('Intensity')
title('Sample 1 raw data','FontWeight','Bold','FontSize',12)
axis tight
subplot(1,2,2)
surf(ExAx,EmAx,squeeze(x(1,:,:)));
ylabel('Emission/nm')
xlabel('Excitation/nm')
zlabel('Intensity')
title('Sample 1 with missing values','FontWeight','Bold','FontSize',12)
axis tight


home
disp(' ')
disp(' ')
disp(' Two different models will be tested:')
disp(' -- Ordinary least squares fitting where emission below excitation ')
disp(' has been set to missing. See the figure to see the same sample')
disp(' as before and after removal of signal.')
disp(' Note that some scatter remains, and sometimes it can be difficult')
disp(' to remove all the scatter, yet still retain all the chemical')
disp(' information')
disp(' ')
disp(' -- MILES fitting where variables corresponding to scatter and emission')
disp(' below excitation is downweighted')
disp(' ')
disp(' Press any key to continue')
pause


%%%%%%%%%% FIT MODELS
disp(' ')
g = input(' Would you like to fit the models or save time and load the result: 1) fit, 2) load: ');
disp(' ')
disp(' ')

if g==1
   disp(' FITTING ordinary LS PARAFAC model')
   model_ls_miss = milesparafac(x,speye(size(W,1)),4);
   disp(' FITTING MILES-PARAFAC model')
   model_ml_miss_scatter = milesparafac(X,W,4);
   save result
else
   disp(' Loading results')
   load result
end

disp(' Press key to see results')
pause
home

c=corrcoef([Y model_ls_miss.loads{1}]);
c = c(1:4,5:8);
corlsmiss = max(abs(c));

disp(' Maximal correlations between LS scores and reference concentrations:')
disp(corlsmiss)

c=corrcoef([Y model_ml_miss_scatter.loads{1}]);
c = c(1:4,5:8);
cormodelmlmissscatter = max(abs(c));

disp(' Maximal correlations between MILES scores and reference concentrations:')
disp(cormodelmlmissscatter)

disp(' ')
disp(' ')
disp(' As can be seen, MILES provide overall better-correlating scores ')
disp(' ')
disp(' Press key to see estimated loadings from the two models')
pause


% PLOT RESULTING LOADINGS
subplot(2,2,1)
l = model_ls_miss.loads{2};l = l*diag(sign(sum(l)));
plot(EmAx,l);
title('Emission')
axis tight
set(gca,'YTick',[0 .25 .5])
ylabel('Loading from LS model')

subplot(2,2,2)
l = model_ls_miss.loads{3};l = l*diag(sign(sum(l)));
plot(ExAx,l);
set(gca,'YTick',[0 .25 .5 .75])
axis tight
title('Excitation')

subplot(2,2,3)
l = model_ml_miss_scatter.loads{2};l = l*diag(sign(sum(l)));
plot(EmAx,l);
set(gca,'YTick',[0 .25 .5])
xlabel('Emission/nm')
ylabel('Loading from MILES model')
axis tight

subplot(2,2,4)
l = model_ml_miss_scatter.loads{3};l = l*diag(sign(sum(l)));
plot(ExAx,l);
set(gca,'YTick',[0 .25 .5])
xlabel('Excitation/nm')
axis tight

home
disp(' ')
disp(' ')
disp(' As can be seen, MILES provide more appropriate loadings ')
disp(' ')
